@@ -1,10 +1,9 @@
 import yaml
 
-from src.models.model import Summarization
-import pandas as pd
+from model import Summarization
 
 
-def predict_model(text):
+def predict_model(text: str):
     """
     Predict the summary of the given text.
     """
@@ -15,9 +14,3 @@ def predict_model(text):
     model.load_model(model_type=params["model_type"], model_dir=params["model_dir"])
     pre_summary = model.predict(text)
     return pre_summary
-
-
-if __name__ == "__main__":
-    text = pd.load_csv("data/processed/test.csv")["input_text"][0]
-    pre_summary = predict_model(text)
-    print(pre_summary)
